@@ -8,6 +8,10 @@ App::Greple::tee - ενότητα για την αντικατάσταση το
 
     greple -Mtee command -- ...
 
+=head1 VERSION
+
+Version 0.9903
+
 =head1 DESCRIPTION
 
 Η ενότητα B<-Mtee> του Greple στέλνει το τμήμα του κειμένου που ταιριάζει με την εντολή φίλτρου που έχει δοθεί και τα αντικαθιστά με το αποτέλεσμα της εντολής. Η ιδέα προέρχεται από την εντολή που ονομάζεται B<teip>. Είναι σαν να παρακάμπτουμε μερικά δεδομένα στην εξωτερική εντολή φίλτρου.
@@ -18,19 +22,15 @@ App::Greple::tee - ενότητα για την αντικατάσταση το
 
 Η παραπάνω εντολή μετατρέπει όλες τις λέξεις που ταιριάζουν από πεζά σε κεφαλαία. Στην πραγματικότητα αυτό το ίδιο το παράδειγμα δεν είναι τόσο χρήσιμο επειδή η B<greple> μπορεί να κάνει το ίδιο πράγμα πιο αποτελεσματικά με την επιλογή B<--cm>.
 
-Από προεπιλογή, η εντολή εκτελείται ως μία μόνο διεργασία και όλα τα δεδομένα που ταιριάζουν αποστέλλονται σε αυτήν αναμεμειγμένα. Αν το κείμενο που ταιριάζει δεν τελειώνει με νέα γραμμή, προστίθεται πριν και αφαιρείται μετά. Τα δεδομένα αντιστοιχίζονται γραμμή προς γραμμή, οπότε ο αριθμός των γραμμών των δεδομένων εισόδου και εξόδου πρέπει να είναι ίδιος.
+Από προεπιλογή, η εντολή εκτελείται ως ενιαία διεργασία και όλα τα δεδομένα που αντιστοιχούν αποστέλλονται στη διεργασία αναμεμειγμένα. Εάν το κείμενο που ταιριάζει δεν τελειώνει με νέα γραμμή, προστίθεται πριν από την αποστολή και αφαιρείται μετά τη λήψη. Τα δεδομένα εισόδου και εξόδου αντιστοιχίζονται γραμμή προς γραμμή, οπότε ο αριθμός των γραμμών εισόδου και εξόδου πρέπει να είναι ίδιος.
 
-Χρησιμοποιώντας την επιλογή B<--discrete>, καλείται μεμονωμένη εντολή για κάθε αντιστοιχισμένο τμήμα. Μπορείτε να καταλάβετε τη διαφορά με τις ακόλουθες εντολές.
+Χρησιμοποιώντας την επιλογή B<--discrete>, καλείται μεμονωμένη εντολή για κάθε αντιστοιχισμένη περιοχή κειμένου. Μπορείτε να καταλάβετε τη διαφορά από τις ακόλουθες εντολές.
 
     greple -Mtee cat -n -- copyright LICENSE
     greple -Mtee cat -n -- copyright LICENSE --discrete
 
 Οι γραμμές των δεδομένων εισόδου και εξόδου δεν χρειάζεται να είναι πανομοιότυπες όταν χρησιμοποιείται η επιλογή B<--discrete>.
 
-=head1 VERSION
-
-Version 0.9902
-
 =head1 OPTIONS
 
 =over 7
@@ -39,9 +39,18 @@ Version 0.9902
 
 Κλήση νέας εντολής ξεχωριστά για κάθε αντιστοιχισμένο τμήμα.
 
+=item B<--bulkmode>
+
+Με την επιλογή <--discrete>, κάθε εντολή εκτελείται κατά παραγγελία. Η επιλογή
+<--bulkmode> option causes all conversions to be performed at once.
+
+=item B<--crmode>
+
+Αυτή η επιλογή αντικαθιστά όλους τους χαρακτήρες νέας γραμμής στη μέση κάθε μπλοκ με χαρακτήρες επιστροφής μεταφορέα. Οι επιστροφές μεταφορέα που περιέχονται στο αποτέλεσμα της εκτέλεσης της εντολής επανέρχονται σε χαρακτήρα νέας γραμμής. Έτσι, τα μπλοκ που αποτελούνται από πολλές γραμμές μπορούν να επεξεργαστούν σε παρτίδες χωρίς τη χρήση της επιλογής B<--discrete>.
+
 =item B<--fillup>
 
-Συνδυάζει μια ακολουθία μη κενών γραμμών σε μια ενιαία γραμμή προτού τις περάσει στην εντολή filter. Οι χαρακτήρες νέας γραμμής μεταξύ ευρέων χαρακτήρων διαγράφονται και οι υπόλοιποι χαρακτήρες νέας γραμμής αντικαθίστανται με κενά.
+Συνδυάστε μια ακολουθία μη κενών γραμμών σε μια ενιαία γραμμή προτού τις περάσετε στην εντολή filter. Οι χαρακτήρες νέας γραμμής μεταξύ χαρακτήρων ευρέος πλάτους διαγράφονται και οι υπόλοιποι χαρακτήρες νέας γραμμής αντικαθίστανται με κενά.
 
 =item B<--blocks>
 
@@ -94,10 +103,10 @@ Version 0.9902
       a) distribute a Standard Version of the executables and library files,
          together with instructions (in the manual page or equivalent) on where to
          get the Standard Version.
-    
+
       b) accompany the distribution with the machine-readable source of the Package
          with your modifications.
-    
+
 Μπορείτε να αναδιαμορφώσετε αυτό το τμήμα χρησιμοποιώντας την ενότητα B<tee> με την εντολή B<ansifold>:
 
     greple -Mtee ansifold -rsw40 --prefix '     ' -- --discrete --re ...
@@ -107,12 +116,12 @@ Version 0.9902
          together with instructions (in the
          manual page or equivalent) on where
          to get the Standard Version.
-    
+
       b) accompany the distribution with the
          machine-readable source of the
          Package with your modifications.
 
-Η χρήση της επιλογής C<--discrete> είναι χρονοβόρα. Έτσι, μπορείτε να χρησιμοποιήσετε την επιλογή C<--διαχωρισμένη '\r'> με την επιλογή C<ansifold> η οποία παράγει μία μόνο γραμμή χρησιμοποιώντας τον χαρακτήρα CR αντί για NL.
+Η επιλογή --discrete θα εκκινήσει πολλαπλές διεργασίες, οπότε η εκτέλεση της διεργασίας θα διαρκέσει περισσότερο. Έτσι, μπορείτε να χρησιμοποιήσετε την επιλογή C<--διαχωρισμός '\r'> με την επιλογή C<ansifold> η οποία παράγει μία μόνο γραμμή χρησιμοποιώντας τον χαρακτήρα CR αντί για NL.
 
     greple -Mtee ansifold -rsw40 --prefix '     ' --separate '\r' --
 
@@ -122,13 +131,13 @@ Version 0.9902
 
 =head1 EXAMPLE 3
 
-Σκεφτείτε μια κατάσταση στην οποία θέλετε να αναζητήσετε με grep συμβολοσειρές από γραμμές που δεν έχουν κεφαλίδα. Για παράδειγμα, μπορεί να θέλετε να αναζητήσετε εικόνες από την εντολή C<docker image ls>, αλλά να αφήσετε τη γραμμή επικεφαλίδας. Μπορείτε να το κάνετε με την ακόλουθη εντολή.
+Σκεφτείτε μια κατάσταση στην οποία θέλετε να αναζητήσετε με grep συμβολοσειρές από γραμμές που δεν έχουν κεφαλίδα. Για παράδειγμα, μπορεί να θέλετε να αναζητήσετε ονόματα εικόνων Docker από την εντολή C<docker image ls>, αλλά να αφήσετε τη γραμμή επικεφαλίδας. Μπορείτε να το κάνετε με την ακόλουθη εντολή.
 
     greple -Mtee grep perl -- -Mline -L 2: --discrete --all
 
-Η επιλογή C<-Mline -L 2:> ανακτά τις προτελευταίες γραμμές και τις στέλνει στην εντολή C<grep perl>. Η επιλογή C<--discrete> είναι απαραίτητη, αλλά αυτή καλείται μόνο μία φορά, οπότε δεν υπάρχει μειονέκτημα στην απόδοση.
+Η επιλογή C<-Mline -L 2:> ανακτά τις προτελευταίες γραμμές και τις στέλνει στην εντολή C<grep perl>. Η επιλογή --discrete απαιτείται επειδή ο αριθμός των γραμμών εισόδου και εξόδου αλλάζει, αλλά επειδή η εντολή εκτελείται μόνο μία φορά, δεν υπάρχει μειονέκτημα απόδοσης.
 
-Σε αυτή την περίπτωση, η C<teip -l 2- -- grep> παράγει σφάλμα επειδή ο αριθμός των γραμμών στην έξοδο είναι μικρότερος από τον αριθμό των γραμμών εισόδου. Ωστόσο, το αποτέλεσμα είναι αρκετά ικανοποιητικό :)
+Αν προσπαθήσετε να κάνετε το ίδιο πράγμα με την εντολή B<teip>, η C<teip -l 2- -- grep> θα δώσει σφάλμα επειδή ο αριθμός των γραμμών εξόδου είναι μικρότερος από τον αριθμό των γραμμών εισόδου. Ωστόσο, δεν υπάρχει κανένα πρόβλημα με το αποτέλεσμα που λαμβάνεται.
 
 =head1 INSTALL
 
@@ -150,7 +159,7 @@ L<App::Greple::xlate>
 
 =head1 BUGS
 
-Η επιλογή C<--fillup> μπορεί να μην λειτουργεί σωστά για κορεατικό κείμενο.
+Η επιλογή C<--fillup> θα αφαιρέσει τα κενά μεταξύ των χαρακτήρων Hangul κατά τη συνένωση κορεατικού κειμένου.
 
 =head1 AUTHOR
 
