@@ -2,35 +2,35 @@
 
 =head1 NAME
 
-App::Greple::tee - マッチしたテキストを外部コマンドの結果に置き換えるモジュールです。
+App::Greple::teeは、マッチしたテキストを外部コマンドの結果に置き換えるモジュールです。
 
 =head1 SYNOPSIS
 
     greple -Mtee command -- ...
 
+=head1 VERSION
+
+Version 0.9903
+
 =head1 DESCRIPTION
 
 Greple の B<-Mtee> モジュールは、マッチしたテキスト部分を指定されたフィルタコマンドに送り、その結果で置き換えます。このアイデアは、B<teip>というコマンドから派生したものです。これは、外部のフィルタコマンドに部分的なデータをバイパスするようなものです。
 
-Filterコマンドはモジュール宣言(C<-Mtee>)に続き、2つのダッシュ(C<-->)で終了します。例えば、次のコマンドは、データ中の一致した単語に対して、C<a-z A-Z> の引数を持つコマンド C<tr> コマンドを呼び出します。
+Filterコマンドはモジュール宣言(Mtee)に続き、2つのダッシュ(--)で終了します。例えば、次のコマンドは、データ中の一致した単語に対して、a-z A-Z の引数を持つコマンド tr コマンドを呼び出します。
 
     greple -Mtee tr a-z A-Z -- '\w+' ...
 
 上記のコマンドは、マッチした単語をすべて小文字から大文字に変換します。B<greple>はB<--cm>オプションでより効果的に同じことができるので、実はこの例自体はあまり意味がありません。
 
-デフォルトでは、このコマンドは一つのプロセスとして実行され、マッチした データはすべて混ぜて送られます。マッチしたテキストが改行で終わっていない場合は、その前に追加され、後に削除されます。データは一行ずつマップされるので、入力データと出力データの行数は同じでなければなりません。
+デフォルトでは、コマンドは1つのプロセスとして実行され、マッチしたデータはすべて混在してプロセスに送られます。マッチしたテキストが改行で終わっていない場合は、送信前に追加され、受信後に削除されます。入力データと出力データは行ごとにマップされるので、入力と出力の行数は同じでなければなりません。
 
-B<--discrete>オプションを使用すると、一致した部品ごとに個別のコマンドが呼び出されます。以下のコマンドを実行すると、その違いが分かります。
+B<--discrete>オプションを使うと、マッチしたテキスト・エリアごとにコマンドが呼び出されます。この違いは以下のコマンドでわかります。
 
     greple -Mtee cat -n -- copyright LICENSE
     greple -Mtee cat -n -- copyright LICENSE --discrete
 
 B<--discrete>オプションを使用する場合、入出力データの行数は同一である必要はありません。
 
-=head1 VERSION
-
-Version 0.9902
-
 =head1 OPTIONS
 
 =over 7
@@ -39,29 +39,38 @@ Version 0.9902
 
 一致した部品に対して、個別に新しいコマンドを起動します。
 
+=item B<--bulkmode>
+
+<--discrete>オプションをつけると、各コマンドはオンデマンドで実行される。このオプションは
+<--bulkmode> option causes all conversions to be performed at once.
+
+=item B<--crmode>
+
+このオプションは、各ブロックの途中にある改行文字をすべてキャリッジリターン文字に置き換えます。コマンドの実行結果に含まれるキャリッジリターンは改行文字に戻されます。このように、複数行からなるブロックは、B<--discrete>オプションを使わずに一括して処理できます。
+
 =item B<--fillup>
 
-空白でない一連の行を、filterコマンドに渡す前に1行にまとめます。幅の広い文字の間の改行文字は削除され、その他の改行文字は空白に置き換えられます。
+一連の空白でない行を1行にまとめてからフィルターコマンドに渡します。幅の広い文字の間の改行文字は削除され、その他の改行文字はスペースに置き換えられます。
 
 =item B<--blocks>
 
 通常、指定された検索パターンにマッチする領域が外部コマンドに送られます。このオプションが指定されると、マッチした領域ではなく、それを含むブロック全体が処理されます。
 
-例えば、パターンC<foo>を含む行を外部コマンドに送るには、行全体にマッチするパターンを指定する必要があります：
+例えば、パターンC<foo>を含む行を外部コマンドに送るには、行全体にマッチするパターンを指定する必要があります。
 
     greple -Mtee cat -n -- '^.*foo.*\n' --all
 
-しかし、B<--blocks> オプションを使えば、次のように簡単にできます：
+しかし、B<--blocks> オプションを使えば、次のように簡単にできます。
 
     greple -Mtee cat -n -- foo --blocks
 
 B<--blocks> オプションをつけると、このモジュールは L<teip(1)> の B<-g> オプションに似た挙動をします。B<--blocks> オプションを使うと、このモジュールはより L<teip(1)> の B<-g> オプションに近い動作をします。
 
-B<--blocks> を B<--all> オプションと一緒に使わないでください。
+B<--blocks> を B<--all> オプションと一緒に使用しないでください。
 
 =item B<--squeeze>
 
-2つ以上の連続する改行文字を1つにまとめます。
+語尾がない文については付け加えずにそのままにする。
 
 =back
 
@@ -69,7 +78,7 @@ B<--blocks> を B<--all> オプションと一緒に使わないでください
 
 まず第一に、B<teip>コマンドでできることは、いつでもそれを使ってください。これは優れたツールで、B<greple>よりずっと速いです。
 
-B<greple>は文書ファイルの処理を目的としているため、マッチエリアの制御など、それに適した機能を多く持っています。それらの機能を活用するために、B<greple>を使う価値はあるかもしれません。
+B<greple>は文書ファイルの処理を目的としているため、マッチエリアの制御など、それに適した機能を多く持っています。それらの機能を活用するために、B<greple>を使う価値があるかもしれません。
 
 また、B<teip>は複数行のデータを1つの単位として扱うことができませんが、B<greple>は複数行からなるデータチャンクに対して個別のコマンドを実行することが可能です。
 
@@ -79,7 +88,7 @@ B<greple>は文書ファイルの処理を目的としているため、マッ
 
     greple --inside '^=(?s:.*?)(^=cut|\z)' --re '^(\w.+\n)+' tee.pm
 
-このようにB<Mtee>モジュールと組み合わせてB<deepl>コマンドを呼び出すと、DeepLサービスによって翻訳することができます。
+このようにB<Mtee>モジュールと組み合わせてB<deepl>コマンドを呼び出すと、DeepLサービスによって翻訳できます。
 
     greple -Mtee deepl text --to JA - -- --fillup ...
 
@@ -94,11 +103,11 @@ B<greple>は文書ファイルの処理を目的としているため、マッ
       a) distribute a Standard Version of the executables and library files,
          together with instructions (in the manual page or equivalent) on where to
          get the Standard Version.
-    
+
       b) accompany the distribution with the machine-readable source of the Package
          with your modifications.
-    
-この部分はB<tee>モジュールとB<ansifold>コマンドで整形することができます。
+
+この部分はB<tee>モジュールとB<ansifold>コマンドで整形できます。
 
     greple -Mtee ansifold -rsw40 --prefix '     ' -- --discrete --re ...
 
@@ -107,12 +116,12 @@ B<greple>は文書ファイルの処理を目的としているため、マッ
          together with instructions (in the
          manual page or equivalent) on where
          to get the Standard Version.
-    
+
       b) accompany the distribution with the
          machine-readable source of the
          Package with your modifications.
 
-C<--discrete> オプションを使うと時間がかかります。そこで、C<--separate ' \r'>オプションとC<ansifold>を併用することで、NLの代わりにCR文字を使って1行を生成することができます。
+discreteオプションは複数のプロセスを起動するので、プロセスの実行に時間がかかります。そのため、C<--separate ' \r'>オプションとC<ansifold>を併用すると、NLの代わりにCR文字を使って1行にできます。
 
     greple -Mtee ansifold -rsw40 --prefix '     ' --separate '\r' --
 
@@ -122,13 +131,13 @@ C<--discrete> オプションを使うと時間がかかります。そこで、
 
 =head1 EXAMPLE 3
 
-ヘッダ行以外から文字列を grep したい場合を考えてみましょう。例えば、C<docker image ls>コマンドから画像を検索したいが、ヘッダ行は残しておきたい場合です。以下のコマンドで可能です。
+ヘッダ行以外から文字列を grep したい場合を考えてみましょう。例えば、C<docker image ls>コマンドからDockerイメージ名を検索したいが、ヘッダ行は残したいとします。以下のコマンドで可能です。
 
     greple -Mtee grep perl -- -Mline -L 2: --discrete --all
 
-オプションC<-Mline -L 2:>は2行目から最後の行を検索し、C<grep perl>コマンドに送ります。オプションC<--discrete>が必要ですが、これは一度しか呼ばれないので、性能上の欠点はありません。
+オプションC<-Mline -L 2:>は2行目から最後の行を検索し、C<grep perl>コマンドに送ります。入出力の行数が変わるので-discreteオプションが必要ですが、コマンドは一度しか実行されないので性能上の欠点はありません。
 
-この場合、C<teip -l 2- -- grep> は出力行数が入力行数より少ないのでエラーになります。しかし、結果は非常に満足のいくものです :)
+B<teip>コマンドで同じことをしようとすると、C<teip -l 2- -- grep>は出力行数が入力行数より少ないのでエラーになりますが、得られる結果に問題はありません。
 
 =head1 INSTALL
 
@@ -138,19 +147,19 @@ C<--discrete> オプションを使うと時間がかかります。そこで、
 
 =head1 SEE ALSO
 
-L<App::Greple::tee>、L<https://github.com/kaz-utashiro/App-Greple-tee>。
+L<App::Greple::tee>は、L<https://github.com/kaz-utashiro/App-Greple-tee>で提供されています。
 
 L<https://github.com/greymd/teip>
 
-L<App::Greple>, L<https://github.com/kaz-utashiro/greple>
+L<App::Greple>, L<https://github.com/kaz-utashiro/greple> です。
 
 L<https://github.com/tecolicom/Greple>
 
-L<App::Greple::xlate>を使用します。
+L<App::Greple::xlate> は、App::Greple::xlate です。
 
 =head1 BUGS
 
-C<--fillup> オプションは韓国語テキストでは正しく動作しないかもしれません。
+C<--fillup> オプションは、韓国語テキストを連結する際に、ハングル文字間の空白を削除します。
 
 =head1 AUTHOR
 
