@@ -8,6 +8,10 @@ App::Greple::tee - модуль для замены совпадающего т
 
     greple -Mtee command -- ...
 
+=head1 VERSION
+
+Version 0.9903
+
 =head1 DESCRIPTION
 
 Модуль Greple's B<-Mtee> посылает совпавшие части текста заданной команде фильтра и заменяет их результатом команды. Идея взята из команды B<teip>. Это подобно обходу частичных данных внешней командой фильтрации.
@@ -18,19 +22,15 @@ App::Greple::tee - модуль для замены совпадающего т
 
 Приведенная выше команда преобразует все совпадающие слова из нижнего регистра в верхний. На самом деле этот пример не так полезен, потому что B<greple> может сделать то же самое более эффективно с помощью опции B<--cm>.
 
-По умолчанию команда выполняется как один процесс, и все совпавшие данные передаются ему вперемешку. Если совпадающий текст не заканчивается новой строкой, она добавляется до и удаляется после. Данные сопоставляются построчно, поэтому количество строк входных и выходных данных должно быть одинаковым.
+По умолчанию команда выполняется как один процесс, и все совпадающие данные отправляются в него вперемешку. Если совпадающий текст не заканчивается новой строкой, то она добавляется перед отправкой и удаляется после получения. Входные и выходные данные сопоставляются построчно, поэтому количество строк ввода и вывода должно быть одинаковым.
 
-При использовании опции B<--discrete> для каждой сопоставленной детали вызывается отдельная команда. Разницу можно определить по следующим командам.
+При использовании опции B<--discrete> для каждой совпадающей области текста вызывается отдельная команда. Разницу можно определить по следующим командам.
 
     greple -Mtee cat -n -- copyright LICENSE
     greple -Mtee cat -n -- copyright LICENSE --discrete
 
 Строки входных и выходных данных не должны быть одинаковыми при использовании опции B<--discrete>.
 
-=head1 VERSION
-
-Version 0.9902
-
 =head1 OPTIONS
 
 =over 7
@@ -39,9 +39,18 @@ Version 0.9902
 
 Вызвать новую команду индивидуально для каждой сопоставленной детали.
 
+=item B<--bulkmode>
+
+При использовании опции <--discrete> каждая команда выполняется по требованию. Опция
+<--bulkmode> option causes all conversions to be performed at once.
+
+=item B<--crmode>
+
+Эта опция заменяет все символы новой строки в середине каждого блока на символы возврата каретки. Возврат каретки, содержащийся в результате выполнения команды, возвращается обратно к символу новой строки. Таким образом, блоки, состоящие из нескольких строк, можно обрабатывать партиями без использования опции B<--discrete>.
+
 =item B<--fillup>
 
-Объедините последовательность непустых строк в одну строку перед передачей их команде фильтра. Символы новой строки между широкими символами удаляются, а другие символы новой строки заменяются пробелами.
+Объединить последовательность непустых строк в одну строку перед передачей ее команде фильтрации. Символы новой строки между символами большой ширины удаляются, а остальные символы новой строки заменяются пробелами.
 
 =item B<--blocks>
 
@@ -94,10 +103,10 @@ Version 0.9902
       a) distribute a Standard Version of the executables and library files,
          together with instructions (in the manual page or equivalent) on where to
          get the Standard Version.
-    
+
       b) accompany the distribution with the machine-readable source of the Package
          with your modifications.
-    
+
 Вы можете переформатировать эту часть, используя модуль B<tee> с командой B<ansifold>:
 
     greple -Mtee ansifold -rsw40 --prefix '     ' -- --discrete --re ...
@@ -107,12 +116,12 @@ Version 0.9902
          together with instructions (in the
          manual page or equivalent) on where
          to get the Standard Version.
-    
+
       b) accompany the distribution with the
          machine-readable source of the
          Package with your modifications.
 
-Использование опции C<--discrete> отнимает много времени. Поэтому вы можете использовать опцию C<--separate '\r'> вместе с C<ansifold>, которая создает одну строку, используя символ CR вместо NL.
+Опция --discrete запускает несколько процессов, поэтому процесс будет выполняться дольше. Поэтому можно использовать опцию C<--separate '\r'> с C<ansifold>, которая выдает одну строку, используя символ CR вместо NL.
 
     greple -Mtee ansifold -rsw40 --prefix '     ' --separate '\r' --
 
@@ -122,13 +131,13 @@ Version 0.9902
 
 =head1 EXAMPLE 3
 
-Рассмотрим ситуацию, когда вы хотите искать строки в строках, не относящихся к заголовкам. Например, вы можете захотеть найти изображения из команды C<docker image ls>, но оставить строку заголовка. Это можно сделать с помощью следующей команды.
+Рассмотрим ситуацию, когда требуется выполнить поиск строк в строках, не являющихся заголовками. Например, нужно найти имена образов Docker из команды C<docker image ls>, но оставить строку заголовка. Это можно сделать с помощью следующей команды.
 
     greple -Mtee grep perl -- -Mline -L 2: --discrete --all
 
-Опция C<-Mline -L 2:> извлекает предпоследние строки и отправляет их команде C<grep perl>. Опция C<--discrete> необходима, но она вызывается только один раз, поэтому недостатка в производительности нет.
+Опция C<-Mline -L 2:> извлекает предпоследние строки и отправляет их в команду C<grep perl>. Опция --discrete необходима, поскольку количество строк ввода и вывода меняется, но поскольку команда выполняется только один раз, то недостатка в производительности нет.
 
-В данном случае команда C<teip -l 2- -- grep> выдает ошибку, так как количество строк на выходе меньше, чем на входе. Однако результат вполне удовлетворительный :)
+Если попытаться сделать то же самое с помощью команды B<teip>, то C<teip -l 2- -- grep> выдаст ошибку, поскольку количество выходных строк меньше количества входных. Однако с полученным результатом проблем нет.
 
 =head1 INSTALL
 
@@ -150,7 +159,7 @@ L<App::Greple::xlate>
 
 =head1 BUGS
 
-Опция C<--fillup> может работать некорректно для корейского текста.
+Опция C<--fillup> удаляет пробелы между символами хангыля при конкатенации корейского текста.
 
 =head1 AUTHOR
 
