@@ -8,6 +8,10 @@ App::Greple::tee - модуль для заміни знайденого тек
 
     greple -Mtee command -- ...
 
+=head1 VERSION
+
+Version 0.9903
+
 =head1 DESCRIPTION
 
 Модуль B<-Mtee> у Greple надсилає частину тексту, що відповідає заданій команді фільтрації, і замінює її на результат команди. Ідея походить від команди з назвою B<teip>. Це схоже на пересилання частини даних до зовнішньої команди фільтрації.
@@ -18,19 +22,15 @@ App::Greple::tee - модуль для заміни знайденого тек
 
 Наведена вище команда перетворює всі знайдені слова з малих літер у великі. Насправді цей приклад не дуже корисний, оскільки B<greple> може зробити те саме ефективніше за допомогою опції B<--cm>.
 
-За замовчуванням команда виконується як окремий процес, і всі знайдені дані надсилаються до нього упереміш. Якщо знайдений текст не закінчується новим рядком, його буде додано до початку і видалено після закінчення. Дані зіставляються рядок за рядком, тому кількість рядків вхідних і вихідних даних має бути однаковою.
+За замовчуванням команда виконується як окремий процес, і всі знайдені дані надсилаються до процесу вперемішку. Якщо знайдений текст не закінчується новим рядком, він додається перед надсиланням і видаляється після отримання. Вхідні та вихідні дані зіставляються рядок за рядком, тому кількість рядків вхідних та вихідних даних має бути однаковою.
 
-Використовуючи опцію B<--discrete>, викликається окрема команда для кожної деталі, що збігається. Ви можете побачити різницю за допомогою наступних команд.
+Використовуючи опцію B<--discrete>, для кожної області тексту, що зіставляється, викликається окрема команда. Ви можете визначити різницю за допомогою наступних команд.
 
     greple -Mtee cat -n -- copyright LICENSE
     greple -Mtee cat -n -- copyright LICENSE --discrete
 
 При використанні опції B<--discrete> рядки вхідних і вихідних даних не обов'язково повинні бути однаковими.
 
-=head1 VERSION
-
-Version 0.9902
-
 =head1 OPTIONS
 
 =over 7
@@ -39,9 +39,18 @@ Version 0.9902
 
 Викликати нову команду окремо для кожної знайденої частини.
 
+=item B<--bulkmode>
+
+З опцією <--discrete> кожна команда виконується на вимогу. Параметр <--дискретний
+<--bulkmode> option causes all conversions to be performed at once.
+
+=item B<--crmode>
+
+Цей параметр замінює усі символи нового рядка у середині кожного блоку на символи повернення каретки. Символи повернення каретки, що містяться у результаті виконання команди, повертаються назад до символу нового рядка. Таким чином, блоки, що складаються з декількох рядків, можна обробляти пакетами без використання опції B<--discrete>.
+
 =item B<--fillup>
 
-Об'єднайте послідовність непустих рядків в один рядок, перш ніж передавати їх команді фільтрації. Символи нового рядка між широкими символами видаляються, а інші символи нового рядка замінюються пробілами.
+Об'єднайте послідовність непорожніх рядків в один рядок, перш ніж передавати їх команді фільтрації. Символи переведення рядка між символами великої ширини буде вилучено, а інші символи переведення рядка буде замінено на пробіли.
 
 =item B<--blocks>
 
@@ -94,10 +103,10 @@ Version 0.9902
       a) distribute a Standard Version of the executables and library files,
          together with instructions (in the manual page or equivalent) on where to
          get the Standard Version.
-    
+
       b) accompany the distribution with the machine-readable source of the Package
          with your modifications.
-    
+
 Ви можете переформатувати цю частину за допомогою модуля B<tee> з командою B<ansifold>:
 
     greple -Mtee ansifold -rsw40 --prefix '     ' -- --discrete --re ...
@@ -107,12 +116,12 @@ Version 0.9902
          together with instructions (in the
          manual page or equivalent) on where
          to get the Standard Version.
-    
+
       b) accompany the distribution with the
          machine-readable source of the
          Package with your modifications.
 
-Використання опції C<--discrete> забирає багато часу. Тому ви можете використовувати опцію C<--separate '\r'> з C<ansifold>, яка створює один рядок з використанням символу CR замість NL.
+Параметр --discrete запускає декілька процесів, тому процес виконуватиметься довше. Тому ви можете скористатися опцією C<--separate '\r'> з C<ansifold>, яка створить один рядок з використанням символу CR замість NL.
 
     greple -Mtee ansifold -rsw40 --prefix '     ' --separate '\r' --
 
@@ -122,13 +131,13 @@ Version 0.9902
 
 =head1 EXAMPLE 3
 
-Розглянемо ситуацію, у якій вам потрібно шукати рядки з рядків, що не є заголовками. Наприклад, ви можете шукати зображення з команди C<docker image ls>, але залишити заголовний рядок. Це можна зробити за допомогою наступної команди.
+Розглянемо ситуацію, у якій вам потрібно шукати рядки з рядків, що не є заголовками. Наприклад, ви можете шукати назви образів Docker за допомогою команди C<docker image ls>, але залишити заголовний рядок. Це можна зробити за допомогою наступної команди.
 
     greple -Mtee grep perl -- -Mline -L 2: --discrete --all
 
-Параметр C<-Mline -L 2:> витягує передостанні рядки і надсилає їх команді C<grep perl>. Опція C<--discrete> є обов'язковою, але вона викликається лише один раз, тому на продуктивності це не позначається.
+Параметр C<-Mline -L 2:> витягує передостанні рядки і надсилає їх команді C<grep perl>. Опція --discrete необхідна, оскільки змінюється кількість рядків вводу і виводу, але оскільки команда виконується лише один раз, це не впливає на продуктивність.
 
-У цьому випадку C<teip -l 2- -- grep> видає помилку, оскільки кількість рядків на виході менша, ніж на вході. Проте, результат цілком задовільний :)
+Якщо ви спробуєте зробити те саме за допомогою команди B<teip>, C<teip -l 2- -- grep> видасть помилку, оскільки кількість рядків виводу менша за кількість рядків вводу. Втім, з отриманим результатом немає жодних проблем.
 
 =head1 INSTALL
 
@@ -146,11 +155,11 @@ L<App::Greple>, L<https://github.com/kaz-utashiro/greple>
 
 L<https://github.com/tecolicom/Greple>
 
-L<App::Greple::xlate>.
+L<App::Greple::xlate>
 
 =head1 BUGS
 
-Опція C<--fillup> може працювати некоректно для корейського тексту.
+Опція C<--fillup> видалить пробіли між символами ханґульської абетки при конкатенації корейського тексту.
 
 =head1 AUTHOR
 
